@@ -16,16 +16,12 @@ The only onterface function is iter_avro, example usage::
 '''
 
 __all__ = [ 'iter_avro' ]
-__version__ = '0.6.0'
+__version__ = '0.6.1'
 
-from sys import version_info
 
 try:
-    if version_info[0] == 3:
-        from . import cfastavro3 as _avro
-    else:
-        from . import cfastavro2 as _avro
-except ImportError:
+    from . import cfastavro as _avro
+except ImportError as e:
     from . import pyfastavro as _avro
 
 reader = iter_avro = _avro.iter_avro
